#!perl -w

use Test::More;
eval "use Test::Pod::Coverage 1.04";
plan skip_all => 'Test::Pod::Coverage 1.04 required for testing POD coverage' if $@;
pod_coverage_ok('Acme::AjiFry');
pod_coverage_ok('Acme::AjiFry::EN');
pod_coverage_ok('Acme::AjiFry::Perl');
done_testing();
