#!/usr/bin/env perl

use 5.12.4;
use strict;
use warnings;
use utf8;

use FindBin;
use lib ("$FindBin::Bin/../lib");
use Acme::AjiFry::Perl;

アジ食え食えアジお刺身フライむむ･･･お刺身むむ･･･アジアジフライ中川"岡星むむ･･･食えアジフライお刺身ドボドボお刺身ドボドボお刺身アジフライ\お刺身むむ･･･";
アジ食え食えアジお刺身フライむむ･･･お刺身むむ･･･アジアジフライ中川"雄山食え食えフライお刺身フライむむ･･･アジむむ･･･中川フライむむ･･･アジむむ･･･\お刺身むむ･･･";
アジ食え食えアジお刺身フライむむ･･･お刺身むむ･･･アジアジフライ中川"山岡ドボドボ食えお刺身お刺身お刺身食えアジフライ::山岡ドボドボフライアジフライフライむむ･･･岡星ドボドボアジお刺身ドボアジフライ::ああドボドボ食えアジフライアジお刺身お刺身ドボドボ\お刺身むむ･･･";
アジ食え食えアジお刺身フライむむ･･･お刺身むむ･･･アジアジフライ中川"ああアジフライ食え食え食えお刺身お刺身アジ食え食えお刺身ドボドボ食えアジフライ中川山岡むむ･･･お刺身アジフライ食えむむ･･･食えアジフライ!\お刺身むむ･･･";
